@@ -5,6 +5,7 @@ from typing import TYPE_CHECKING
 
 import attr
 
+from applitools.common.accessibility import AccessibilitySettings
 from applitools.common.geometry import RectangleSize
 from applitools.common.match import ImageMatchSettings, MatchLevel
 from applitools.common.server import FailureReports, SessionType
@@ -39,19 +40,21 @@ class BatchInfo(object):
         metadata={JsonInclude.NAME: "batchSequenceName"}
     )  # type: Optional[Text]
     id = attr.ib(metadata={JsonInclude.THIS: True})  # type: Text
-    notify_on_completion = attr.ib(metadata={JsonInclude.NON_NONE: True})
+    notify_on_completion = attr.ib(metadata={JsonInclude.NON_NONE: True})  # type: bool
 
     def __init__(self, name=None, started_at=None, batch_sequence_name=None):
         # type: (Optional[Text], Optional[datetime], Optional[Text]) -> None
         self.id = get_env_with_prefix(
             "APPLITOOLS_BATCH_ID", str(uuid.uuid4())
         )  # type: Text
-        self.name = get_env_with_prefix("APPLITOOLS_BATCH_NAME")
-        self.started_at = datetime.now(UTC)
-        self.sequence_name = get_env_with_prefix("APPLITOOLS_BATCH_SEQUENCE")
+        self.name = get_env_with_prefix("APPLITOOLS_BATCH_NAME")  # type: Text
+        self.started_at = datetime.now(UTC)  # type: datetime
+        self.sequence_name = get_env_with_prefix(
+            "APPLITOOLS_BATCH_SEQUENCE"
+        )  # type: Optional[Text]
         self.notify_on_completion = str2bool(
             get_env_with_prefix("APPLITOOLS_BATCH_NOTIFY")
-        )
+        )  # type: bool
 
         if name:
             self.name = name
@@ -102,7 +105,6 @@ class Configuration(object):
         factory=ImageMatchSettings
     )  # type: ImageMatchSettings
     stitch_overlap = attr.ib(default=5)  # type: int
-
     api_key = attr.ib(
         factory=lambda: get_env_with_prefix("APPLITOOLS_API_KEY", None)
     )  # type: Optional[Text]
@@ -113,35 +115,43 @@ class Configuration(object):
 
     @property
     def enable_patterns(self):
+        # type: () -> bool
         return self.default_match_settings.enable_patterns
 
     @enable_patterns.setter
-    def enable_patterns(self, value):
-        self.default_match_settings.enable_patterns = value
+    def enable_patterns(self, enable_patterns):
+        # type: (bool) -> None
+        self.default_match_settings.enable_patterns = enable_patterns
 
     @property
     def use_dom(self):
+        # type: () -> bool
         return self.default_match_settings.use_dom
 
     @use_dom.setter
-    def use_dom(self, value):
-        self.default_match_settings.use_dom = value
+    def use_dom(self, use_dom):
+        # type: (bool) -> None
+        self.default_match_settings.use_dom = use_dom
 
     @property
     def match_level(self):
+        # type: () -> MatchLevel
         return self.default_match_settings.match_level
 
     @match_level.setter
-    def match_level(self, value):
-        self.default_match_settings.match_level = value
+    def match_level(self, match_level):
+        # type: (MatchLevel) -> None
+        self.default_match_settings.match_level = match_level
 
     @property
     def ignore_displacements(self):
+        # type: () -> bool
         return self.default_match_settings.ignore_displacements
 
     @ignore_displacements.setter
-    def ignore_displacements(self, value):
-        self.default_match_settings.ignore_displacements = value
+    def ignore_displacements(self, ignore_displacements):
+        # type: (bool) -> None
+        self.default_match_settings.ignore_displacements = ignore_displacements
 
     def set_batch(self, batch):
         # type: (Self, BatchInfo) -> Self
@@ -290,6 +300,25 @@ class Configuration(object):
         self.default_match_settings = default_match_settings
         return self
 
+    @property
+    def accessibility_validation(self):
+        # type: (Self) -> Optional[AccessibilitySettings]
+        return self.default_match_settings.accessibility_settings
+
+    @accessibility_validation.setter
+    def accessibility_validation(self, accessibility_settings):
+        # type: (Self, Optional[AccessibilitySettings]) -> None
+        if accessibility_settings is None:
+            self.self.default_match_settings.accessibility_settings = None
+            return
+        argument_guard.is_a(accessibility_settings, AccessibilitySettings)
+        self.default_match_settings.accessibility_settings = accessibility_settings
+
+    def set_accessibility_validation(self, accessibility_settings):
+        # type: (Self, Optional[AccessibilitySettings]) -> Self
+        self.accessibility_validation = accessibility_settings
+        return self
+
     @match_timeout.validator
     def _validate1(self, attribute, value):
         if 0 < value < MINIMUM_MATCH_TIMEOUT_MS:
