@@ -2,19 +2,20 @@ from __future__ import absolute_import
 
 import math
 from enum import Enum
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union, overload
+from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union, overload, Text
 
 import attr
 from PIL.Image import Image
 
 from . import logger
+from .accessibility import AccessibilityRegionType
 from .mixins import DictAccessMixin
 from .utils import argument_guard
+from .utils.compat import basestring
 from .utils.converters import round_converter
 from .utils.json_utils import JsonInclude
 
 if TYPE_CHECKING:
-    from .utils.custom_types import ViewPort
     from .visual_grid import EmulationDevice
 
 __all__ = (
@@ -58,17 +59,13 @@ class CoordinatesType(Enum):
 class RectangleSize(DictAccessMixin):
     """Represents a 2D size"""
 
-    width = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    height = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type:int
+    width = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    height = attr.ib(metadata={JsonInclude.THIS: True})  # type:int
 
     def __init__(self, width, height):
         # type: (int, int) -> None
-        self.width = width
-        self.height = height
+        self.width = round_converter(width)
+        self.height = round_converter(height)
 
     def __str__(self):
         return "RectangleSize({width} x {height})".format(
@@ -106,17 +103,13 @@ class RectangleSize(DictAccessMixin):
 class Point(DictAccessMixin):
     """A location in a two-dimensional plane."""
 
-    x = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    y = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
+    x = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    y = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
 
     def __init__(self, x, y):
         # type: (int, int) -> None
-        self.x = x
-        self.y = y
+        self.x = round_converter(x)
+        self.y = round_converter(y)
 
     def __str__(self):
         return "Point({x} x {y})".format(x=self.x, y=self.y)
@@ -209,24 +202,11 @@ class Point(DictAccessMixin):
 
 
 @attr.s(slots=True, init=False)
-class Region(DictAccessMixin):
-    """A rectangle identified by left,top, width, height."""
-
-    left = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    top = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    width = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    height = attr.ib(
-        converter=round_converter, metadata={JsonInclude.THIS: True}
-    )  # type: int
-    coordinates_type = attr.ib(
-        metadata={JsonInclude.THIS: True}
-    )  # type: CoordinatesType
+class Rectangle(DictAccessMixin):
+    left = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    top = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    width = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    height = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
 
     def __init__(
         self,
@@ -234,67 +214,17 @@ class Region(DictAccessMixin):
         top,  # type: int
         width,  # type: int
         height,  # type: int
-        coordinates_type=CoordinatesType.SCREENSHOT_AS_IS,  # type: CoordinatesType
     ):
         # type: (...) -> None
-        self.left = left
-        self.top = top
-        self.width = width
-        self.height = height
-        self.coordinates_type = coordinates_type
-
-    def __str__(self):
-        return "Region({left}, {top}, {width} x {height}, {type})".format(
-            left=self.left,
-            top=self.top,
-            width=self.width,
-            height=self.height,
-            type=self.coordinates_type.value,
-        )
+        self.left = round_converter(left)
+        self.top = round_converter(top)
+        self.width = round_converter(width)
+        self.height = round_converter(height)
 
     @classmethod  # noqa
     def EMPTY(cls):
         return cls(0, 0, 0, 0)
 
-    @classmethod  # noqa
-    @overload
-    def from_(cls, location, image):
-        # type: (Union[Point, Dict], Image) -> Region
-        pass
-
-    @classmethod  # noqa
-    @overload
-    def from_(cls, location, size):
-        # type: (Union[Point, Dict], Union[Dict,RectangleSize]) -> Region
-        pass
-
-    @classmethod  # noqa
-    @overload
-    def from_(cls, image):
-        # type: (Image) -> Region
-        pass
-
-    @classmethod  # noqa
-    @overload
-    def from_(cls, region):
-        # type: (Region) -> Region
-        pass
-
-    @classmethod  # noqa
-    def from_(cls, obj, obj2=None):
-        # type: (Union[Region,Image,Point,Dict],Union[Dict,RectangleSize,Image])->Region
-        """Creates a new Region instance."""
-        if isinstance(obj, Region):
-            return cls(obj.left, obj.top, obj.width, obj.height, obj.coordinates_type)
-        elif isinstance(obj, Image):
-            return cls(0, 0, obj.width, obj.height)
-        elif isinstance(obj, Point) or isinstance(obj, dict) and obj2:
-            if isinstance(obj2, Image):
-                return cls(obj["x"], obj["y"], obj2.width, obj2.height)
-            else:
-                return cls(obj["x"], obj["y"], obj2["width"], obj2["height"])
-        raise ValueError("Wrong parameters passed")
-
     @property
     def x(self):
         # type: () -> int
@@ -350,16 +280,6 @@ class Region(DictAccessMixin):
         """
         return RectangleSize(width=self.width, height=self.height)
 
-    def clone(self):
-        # type: () -> Region
-        """
-        Returns:
-            The cloned instance of Region.
-        """
-        return Region(
-            self.left, self.top, self.width, self.height, self.coordinates_type
-        )
-
     def make_empty(self):
         """Sets the current instance as an empty instance"""
         self.left = self.top = self.width = self.height = 0
@@ -388,6 +308,219 @@ class Region(DictAccessMixin):
         """
         return self.left == self.top == self.width == self.height == 0
 
+    @property
+    def middle_offset(self):
+        # type: () -> Point
+        return Point(int(round(self.width / 2)), int(round(self.height / 2)))
+
+    @overload  # noqa
+    def offset(self, location):
+        # type: (Point) -> Region
+        pass
+
+    @overload  # noqa
+    def offset(self, dx, dy):
+        # type: (int, int) -> Region
+        pass
+
+    def offset(self, location_or_dx, dy=None):  # noqa
+        # type: (Union[Point, int], Optional[int]) -> Rectangle
+        """Get an offset region.
+
+        Args:
+            location_or_dx: Full amount to offset or just x-coordinate
+            dy: The amount to offset the y-coordinate.
+
+        Returns:
+            A region with an offset location.
+        """
+        dx, dy = dx_and_dy(location_or_dx, dy)
+        location = self.location.offset(dx, dy)
+        return Rectangle(
+            left=location.x,
+            top=location.y,
+            width=self.size["width"],
+            height=self.size["height"],
+        )
+
+
+@attr.s(slots=True, init=False)
+class AccessibilityRegion(Rectangle):
+    """A rectangle identified by left,top, width, height."""
+
+    left = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    top = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    width = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    height = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    type = attr.ib(
+        type=AccessibilityRegionType, metadata={JsonInclude.THIS: True},
+    )  # type: AccessibilityRegionType
+
+    def __init__(
+        self,
+        left,  # type: int
+        top,  # type: int
+        width,  # type: int
+        height,  # type: int
+        type,  # type: Union[Text, AccessibilityRegionType]
+    ):
+        # type: (...) -> None
+        super(AccessibilityRegion, self).__init__(left, top, width, height)
+        if isinstance(type, basestring):
+            if type == "None":
+                self.type = None
+                return
+            self.type = AccessibilityRegionType(type)
+            return
+        argument_guard.is_a(type, AccessibilityRegionType)
+        self.type = type
+
+    @overload  # noqa
+    def from_(self, accessibility_region):
+        # type: (Union[Dict, AccessibilityRegion]) -> AccessibilityRegion
+        pass
+
+    @overload  # noqa
+    def from_(self, region, accessibility_type):
+        # type: (Union[Region,Rectangle],AccessibilityRegionType)->AccessibilityRegion
+        pass
+
+    @classmethod  # noqa
+    def from_(cls, obj, obj2=None):
+        # type: (...)->AccessibilityRegion
+        """Creates a new Region instance."""
+        if isinstance(obj, AccessibilityRegion):
+            return cls(obj.left, obj.top, obj.width, obj.height, obj.type)
+        elif (
+            isinstance(obj, Region)
+            or isinstance(obj, Rectangle)
+            and isinstance(obj2, AccessibilityRegionType)
+        ):
+            return cls(obj.left, obj.top, obj.width, obj.height, obj2)
+        elif isinstance(obj, dict):
+            return cls(
+                obj["left"],
+                obj["top"],
+                obj["width"],
+                obj["height"],
+                AccessibilityRegionType(obj["type"]),
+            )
+        raise ValueError("Wrong parameters passed")
+
+    def offset(self, location_or_dx, dy=None):  # noqa
+        # type: (Union[Point, int], Optional[int]) -> AccessibilityRegion
+        r = super(AccessibilityRegion, self).offset(location_or_dx, dy)
+        return AccessibilityRegion.from_(r, self.type)
+
+
+@attr.s(slots=True, init=False)
+class Region(Rectangle):
+    """A rectangle identified by left,top, width, height."""
+
+    left = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    top = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    width = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    height = attr.ib(metadata={JsonInclude.THIS: True})  # type: int
+    coordinates_type = attr.ib(
+        converter=CoordinatesType,
+        type=CoordinatesType,
+        metadata={JsonInclude.THIS: True},
+    )  # type: CoordinatesType
+
+    def __init__(
+        self,
+        left,  # type: int
+        top,  # type: int
+        width,  # type: int
+        height,  # type: int
+        coordinates_type=CoordinatesType.SCREENSHOT_AS_IS,  # type:Union[Text,CoordinatesType]
+    ):
+        # type: (...) -> None
+        super(Region, self).__init__(left, top, width, height)
+        if isinstance(coordinates_type, basestring):
+            self.coordinates_type = CoordinatesType(coordinates_type)
+            return
+        argument_guard.is_a(coordinates_type, CoordinatesType)
+        self.coordinates_type = coordinates_type
+
+    def __str__(self):
+        return "Region({left}, {top}, {width} x {height}, {type})".format(
+            left=self.left,
+            top=self.top,
+            width=self.width,
+            height=self.height,
+            type=self.coordinates_type.value,
+        )
+
+    @classmethod  # noqa
+    @overload
+    def from_(cls, location, image):
+        # type: (Union[Point, Dict], Image) -> Region
+        pass
+
+    @classmethod  # noqa
+    @overload
+    def from_(cls, location, size):
+        # type: (Union[Point, Dict], Union[Dict,RectangleSize]) -> Region
+        pass
+
+    @classmethod  # noqa
+    @overload
+    def from_(cls, image):
+        # type: (Image) -> Region
+        pass
+
+    @classmethod  # noqa
+    @overload
+    def from_(cls, region):
+        # type: (Union[Region, Dict]) -> Region
+        pass
+
+    @classmethod  # noqa
+    @overload
+    def from_(cls, rectangle, coordinates_type):
+        # type: (Rectangle, Optional[CoordinatesType]) -> Region
+        pass
+
+    @classmethod  # noqa
+    def from_(cls, obj, obj2=None):
+        # type:( ... )->Region
+        """Creates a new Region instance."""
+        if isinstance(obj, Rectangle):
+            if isinstance(obj2, CoordinatesType):
+                return cls(obj.left, obj.top, obj.width, obj.height, obj2)
+            return cls(obj.left, obj.top, obj.width, obj.height)
+        if isinstance(obj, Region):
+            return cls(obj.left, obj.top, obj.width, obj.height, obj.coordinates_type)
+        elif isinstance(obj, Image):
+            return cls(0, 0, obj.width, obj.height)
+        elif isinstance(obj, Point) or isinstance(obj, dict) and obj2:
+            if isinstance(obj2, Image):
+                return cls(obj["x"], obj["y"], obj2.width, obj2.height)
+            else:
+                return cls(obj["x"], obj["y"], obj2["width"], obj2["height"])
+        elif isinstance(obj, dict) and obj2 is None:
+            return cls(
+                obj[
+                    "left",
+                    obj["right"],
+                    obj["height"],
+                    obj["width"],
+                    CoordinatesType(obj["type"]),
+                ]
+            )
+        raise ValueError("Wrong parameters passed")
+
+    def clone(self):
+        # type: () -> Region
+        """
+        Returns:
+            The cloned instance of Region.
+        """
+        return Region(
+            self.left, self.top, self.width, self.height, self.coordinates_type
+        )
+
     def contains(self, other):
         # type: (Union[Point, Region]) -> bool
         """Return true if a point is inside the rectangle.
@@ -430,6 +563,9 @@ class Region(DictAccessMixin):
             or other.top <= self.top <= other.bottom
         )
 
+    def is_intersected(self, other):
+        return self.overlaps(other)
+
     def intersect(self, other):
         # type: (Region) -> Region
         # If the regions don't overlap, the intersection is empty
@@ -581,41 +717,10 @@ class Region(DictAccessMixin):
 
         return sub_regions
 
-    @property
-    def middle_offset(self):
-        # type: () -> Point
-        return Point(int(round(self.width / 2)), int(round(self.height / 2)))
-
-    @overload  # noqa
-    def offset(self, location):
-        # type: (Point) -> Region
-        pass
-
-    @overload  # noqa
-    def offset(self, dx, dy):
-        # type: (int, int) -> Region
-        pass
-
     def offset(self, location_or_dx, dy=None):  # noqa
         # type: (Union[Point, int], Optional[int]) -> Region
-        """Get an offset region.
-
-        Args:
-            location_or_dx: Full amount to offset or just x-coordinate
-            dy: The amount to offset the y-coordinate.
-
-        Returns:
-            A region with an offset location.
-        """
-        dx, dy = dx_and_dy(location_or_dx, dy)
-        location = self.location.offset(dx, dy)
-        return Region(
-            left=location.x,
-            top=location.y,
-            width=self.size["width"],
-            height=self.size["height"],
-            coordinates_type=self.coordinates_type,
-        )
+        r = super(Region, self).offset(location_or_dx, dy)
+        return Region.from_(r, self.coordinates_type)
 
     def scale(self, scale_ratio):
         # type: (float) -> Region
