@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING, List, Optional, Text
 import attr
 
 from applitools.common.utils.json_utils import JsonInclude
+from .accessibility import SessionAccessibilityStatus
 
 from .geometry import RectangleSize
 from .match import ImageMatchSettings
@@ -114,7 +115,10 @@ class TestResults(object):
         init=False, default=None, metadata={JsonInclude.THIS: True}
     )  # type: Optional[Text]
     status = attr.ib(
-        default=None, repr=False, metadata={JsonInclude.THIS: True}
+        converter=TestResultsStatus,
+        default=None,
+        repr=False,
+        metadata={JsonInclude.THIS: True},
     )  # type: Optional[Text]
 
     name = attr.ib(
@@ -182,27 +186,26 @@ class TestResults(object):
         type=ImageMatchSettings,
         metadata={JsonInclude.THIS: True},
     )  # type: ImageMatchSettings
+    accessibility_status = attr.ib(
+        default=None,
+        type=SessionAccessibilityStatus,
+        metadata={JsonInclude.THIS: True},
+    )  # type: SessionAccessibilityStatus
 
     @property
     def is_passed(self):
         # type: () -> bool
-        return (
-            self.status is not None
-        ) and self.status.lower() == TestResultsStatus.Passed.name.lower()
+        return self.status == TestResultsStatus.Passed
 
     @property
     def is_unresolved(self):
         # type: () -> bool
-        return (
-            self.status is not None
-        ) and self.status.lower() == TestResultsStatus.Unresolved.name.lower()
+        return self.status == TestResultsStatus.Unresolved
 
     @property
     def is_failed(self):
         # type: () -> bool
-        return (
-            self.status is not None
-        ) and self.status.lower() == TestResultsStatus.Failed.name.lower()
+        return self.status == TestResultsStatus.Failed
 
     def __str__(self):
         origin_str = super(TestResults, self).__str__()
