@@ -7,7 +7,7 @@ import typing
 
 import attr
 
-from .compat import parse_qs, urlencode, urlparse, urlsplit, urlunsplit
+from .compat import parse_qs, urlencode, urlsplit, urlunsplit
 
 """
 General purpose utilities.
@@ -50,14 +50,6 @@ def cached_property(f):
     return property(get)
 
 
-def is_absolute_url(url):
-    return bool(urlparse(url).netloc)
-
-
-def is_url_with_scheme(url):
-    return bool(urlparse(url).scheme)
-
-
 def get_sha256_hash(content):
     return hashlib.sha256(content).hexdigest()
 
@@ -79,11 +71,14 @@ def set_query_parameter(url, param_name, param_value):
     return urlunsplit((scheme, netloc, path, new_query_string, fragment))
 
 
-def proxy_to(proxy_obj_name, fields):
-    # type: (Text, List[Text]) -> Callable
+def proxy_to(proxy_obj_name, fields=None):
+    # type: (Text, Optional[List[Text]]) -> Callable
     """
     Adds to decorated class __getter__ and __setter__ methods that allow to access
-    attributes from proxy_object in the parent class
+    attributes from proxy_object in the parent class.
+
+    :exception Decorator should be used only on highest class in hierarchy otherwise the
+    RuntimeError will happen because recursion.
 
     :param proxy_obj_name: The name of the proxy object that has decorated class.
     :param fields:
@@ -91,7 +86,8 @@ def proxy_to(proxy_obj_name, fields):
     """
 
     def __getattr__(self, name):
-        if name in fields:
+        _fields = fields or self._proxy_to_fields or []
+        if name in _fields:
             proxy_obj = getattr(self, proxy_obj_name)
             return getattr(proxy_obj, name)
         module_with_class = "{}::{}".format(
@@ -100,15 +96,23 @@ def proxy_to(proxy_obj_name, fields):
         raise AttributeError("{} has not attr `{}`".format(module_with_class, name))
 
     def __setattr__(self, key, value):
-        if key in fields:
+        _fields = fields or self._proxy_to_fields or []
+        if key in _fields:
             proxy_obj = getattr(self, proxy_obj_name)
             setattr(proxy_obj, key, value)
         else:
             super(self.__class__, self).__setattr__(key, value)
 
+    def __dir__(self):
+        _fields = fields or self._proxy_to_fields or []
+        origin_fields = super(self.__class__, self).__dir__()
+        return list(origin_fields) + _fields
+
     def dec(cls):
+        cls._proxy_to_fields = None
         cls.__getattr__ = __getattr__
         cls.__setattr__ = __setattr__
+        cls.__dir__ = __dir__
         return cls
 
     return dec
@@ -130,6 +134,19 @@ def all_fields(obj):
         return [f for f in vars(obj) if not f.startswith("_")]
 
 
+def all_attrs(obj):
+    # type: (Any) -> List[Text]
+    """Get all public attributes from the object. Methods and fields.
+
+    Args:
+        obj: any kind object
+
+    Returns:
+        list of attributes and methods names
+    """
+    return [f for f in dir(obj) if not f.startswith("_")]
+
+
 def get_env_with_prefix(env_name, default=None):
     # type: (Text, Optional[Text]) -> Optional[Text]
     """
@@ -145,3 +162,29 @@ def get_env_with_prefix(env_name, default=None):
             if value:
                 return value
     return default
+
+
+def counted(f):
+    """
+    Decorator that tracks how many times the function is called
+    """
+
+    def wrapped(*args, **kwargs):
+        wrapped.calls += 1
+        return f(*args, **kwargs)
+
+    wrapped.calls = 0
+    return wrapped
+
+
+class DynamicEnumGetter(object):
+    """
+    Allow to use methods as values in Enum classes
+    """
+
+    def __init__(self, fget=None):
+        self.fget = fget
+        self.__doc__ = fget.__doc__
+
+    def __get__(self, instance, ownerclass=None):
+        return self.fget(ownerclass)
